@@ -22,8 +22,9 @@ Example:
 
         $ pyppyn --help
 """
+
 from __future__ import (
-    absolute_import,
+    absolute_import,  # __init__.py pylint: disable=duplicate-code
     division,
     print_function,
     unicode_literals,
@@ -42,7 +43,7 @@ import sys
 import uuid
 import zipfile
 
-__version__ = "0.3.51"
+__version__ = "0.3.52"
 
 __EXITOKAY__ = 0
 FILE_DIR = ".pyppyn"
