@@ -1,7 +1,12 @@
 # -*- coding: utf-8 -*-
 """minipippy test module."""
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals, with_statement)
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+    with_statement,
+)
 
 if __name__ == "__main__":
 
